@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-09-15'; # DATE
-our $VERSION = '1.30'; # VERSION
+our $DATE = '2015-09-17'; # DATE
+our $VERSION = '1.31'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -259,7 +259,7 @@ sub hook_format_result {
 
     # ux: prefix error message with program name
     if ($fmt =~ /text/ && $r->{res}[0] =~ /\A[45]/ && defined($r->{res}[1])) {
-        $fres = "$self->{program_name}: $fres";
+        $fres = $self->program_name . ": $fres";
     }
 
     $fres;
@@ -449,7 +449,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 1.30 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-09-15.
+This document describes version 1.31 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-09-17.
 
 =head1 SYNOPSIS
 
